@@ -4,4 +4,5 @@ pub mod Config;
 pub use Config::*;
 pub mod routes;
 pub use routes::*;
-
+pub mod Web;
+pub use Web::*;
